=====================================================================
 `xotl.tools.dim`:mod: - Facilities to work with `concrete numbers`_
=====================================================================

.. module:: xotl.tools.dim

The name 'dim' is a short of dimension.  We borrow it from the topic
`dimensional analysis`_, even though the scope of this module is less
ambitious.

This module is divided in two major parts: meta-definitions and applications.

.. toctree::
   :glob:

   dim/meta
   dim/*

.. _concrete numbers: https://en.wikipedia.org/wiki/Concrete_number
.. _dimensional analysis: https://en.wikipedia.org/wiki/Dimensional_analysis
